"use strict";
// This file is part of charto-leaflet, copyright (c) 2017 BusFaster Ltd.
// Released under the MIT license, see LICENSE.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var L = require("leaflet");
exports.BaseCRS = (function () { });
exports.BaseCRS.prototype = L.CRS;
/** Custom CRS using zoom levels configured in the background map. */
var CRS = /** @class */ (function (_super) {
    __extends(CRS, _super);
    function CRS(code, projection, 
        /** Default: ensure longitude is positive and flip latitude. */
        transformation) {
        if (transformation === void 0) { transformation = new L.Transformation(1, -Math.min(0, projection.bounds.min.x), -1, 0); }
        var _this = _super.call(this) || this;
        _this.code = code;
        _this.projection = projection;
        _this.transformation = transformation;
        // Get maximum dimension of projection bounds and divide by tile size in pixels.
        var size = projection.bounds.getSize();
        _this.range = Math.max(size.x, size.y) / 256;
        return _this;
    }
    CRS.prototype.distance = function (ll1, ll2) {
        var dlat = ll2.lat - ll1.lat;
        var dlon = ll2.lng - ll1.lng;
        return (Math.sqrt(dlat * dlat + dlon * dlon));
    };
    CRS.prototype.scale = function (zoom) {
        return ((1 << zoom) / this.range);
    };
    /** Needed for zooming to box by shift-dragging. */
    CRS.prototype.zoom = function (scale) {
        return (Math.log(scale * this.range) / Math.LN2);
    };
    return CRS;
}(exports.BaseCRS));
exports.CRS = CRS;
//# sourceMappingURL=CRS.js.map